From eacc2561d14dbe9cba6966e3b32bfd776e044f8a Mon Sep 17 00:00:00 2001
From: Robert Adams
Date: Thu, 10 Jan 2013 17:03:19 -0800
Subject: BulletSim: add osGetPhysicsEngineType() LSL function and update the
physics engines to return the name that is specified in the INI file
("physics = XXX") as the type of engine. This os function is a little
different than the others in that it does not throw an exception of one is
not privilaged to use it. It merely returns an empty string.
---
OpenSim/Region/Physics/Manager/PhysicsScene.cs | 11 +++++++++--
1 file changed, 9 insertions(+), 2 deletions(-)
(limited to 'OpenSim/Region/Physics/Manager/PhysicsScene.cs')
diff --git a/OpenSim/Region/Physics/Manager/PhysicsScene.cs b/OpenSim/Region/Physics/Manager/PhysicsScene.cs
index 488900e..201007b 100644
--- a/OpenSim/Region/Physics/Manager/PhysicsScene.cs
+++ b/OpenSim/Region/Physics/Manager/PhysicsScene.cs
@@ -62,13 +62,20 @@ namespace OpenSim.Region.Physics.Manager
// private static readonly ILog m_log = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);
///
/// Name of this scene. Useful in debug messages to distinguish one OdeScene instance from another.
///
public string Name { get; protected set; }
+ ///
+ /// A string identifying the family of this physics engine. Most common values returned
+ /// are "OpenDynamicsEngine" and "BulletSim" but others are possible.
+ ///
+ public string EngineType { get; protected set; }
+
// The only thing that should register for this event is the SceneGraph
// Anything else could cause problems.
-
public event physicsCrash OnPhysicsCrash;
public static PhysicsScene Null
@@ -62,13 +62,20 @@ namespace OpenSim.Region.Physics.Manager
// private static readonly ILog m_log = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);
///
- /// Name of this scene. Useful in debug messages to distinguish one OdeScene instance from another.
+ /// A unique identifying string for this instance of the physics engine.
+ /// Useful in debug messages to distinguish one OdeScene instance from another.
+ /// Usually set to include the region name that the physics engine is acting for.
///
public string Name { get; protected set; }
--
cgit v1.1